// Copyright (c) Mito
import React, { forwardRef, useEffect } from 'react';
import '../../../css/elements/Input.css';
import { classNames } from '../../utils/classNames';
/**
 * The input component is a text field that allows the user
 * to input a single item. It is meant for a single line of text,
 * like an email!
 *
 * Note that this component uses the forwardRef pattern, as is
 * explained here: https://reactjs.org/docs/forwarding-refs.html
 *
 * At a high-level, this allows us to have parent components access
 * refs for the input (which is necessary as we sometimes need the ref
 * to focus on this input).
 */
const Input = forwardRef(function Input(props, 
/**
    * @param [ref] - An optional ref that is set by the input field so that the creating component can access it
*/
ref) {
    // Create better default values to handle optional params 
    const width = props.width || 'block';
    const autoFocus = props.autoFocus || false;
    const widthClass = `element-width-${width}`;
    /*
        Setting the autoFocus field on the input element only seems to work when the input field
        is inside of a form. Many times, the input fields we want to autofocus on is not part of a
        form in Mito. So here, we manually set the focus.
    */
    useEffect(() => {
        var _a;
        if (autoFocus && ref !== undefined && ref !== null && typeof ref == 'object') {
            (_a = ref.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
    }, []);
    return (React.createElement("input", { className: classNames('input', 'text-body-2', widthClass), value: props.value, placeholder: props.placeholder, onChange: props.onChange, autoFocus: props.autoFocus, required: props.required, disabled: props.disabled, ref: ref }));
});
export default Input;
//# sourceMappingURL=Input.js.map